==> zio-aws-pinpoint_3-5.17.104.12-sources.jar: zio/aws/pinpoint/model/UntagResourceRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class UntagResourceRequest(
    resourceArn: __string,
    tagKeys: Iterable[__string]
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.UntagResourceRequest = {
    import UntagResourceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.UntagResourceRequest
      .builder()
      .resourceArn(__string.unwrap(resourceArn): java.lang.String)
      .tagKeys(tagKeys.map { item =>
        __string.unwrap(item): java.lang.String
      }.asJavaCollection)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.UntagResourceRequest.ReadOnly =
    zio.aws.pinpoint.model.UntagResourceRequest.wrap(buildAwsValue())
}
object UntagResourceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.UntagResourceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.UntagResourceRequest =
      zio.aws.pinpoint.model.UntagResourceRequest(resourceArn, tagKeys)
    def resourceArn: __string
    def tagKeys: List[__string]
    def getResourceArn: ZIO[Any, Nothing, __string] = ZIO.succeed(resourceArn)
    def getTagKeys: ZIO[Any, Nothing, List[__string]] = ZIO.succeed(tagKeys)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.UntagResourceRequest
  ) extends zio.aws.pinpoint.model.UntagResourceRequest.ReadOnly {
    override val resourceArn: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.resourceArn())
    override val tagKeys: List[__string] = impl
      .tagKeys()
      .asScala
      .map { item =>
        zio.aws.pinpoint.model.primitives.__string(item)
      }
      .toList
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.UntagResourceRequest
  ): zio.aws.pinpoint.model.UntagResourceRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-pinpoint_3-6.20.78.3-sources.jar: zio/aws/pinpoint/model/UntagResourceRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class UntagResourceRequest(
    resourceArn: __string,
    tagKeys: Iterable[__string]
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.UntagResourceRequest = {
    import UntagResourceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.UntagResourceRequest
      .builder()
      .resourceArn(resourceArn: java.lang.String)
      .tagKeys(tagKeys.map { item =>
        item: java.lang.String
      }.asJavaCollection)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.UntagResourceRequest.ReadOnly =
    zio.aws.pinpoint.model.UntagResourceRequest.wrap(buildAwsValue())
}
object UntagResourceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.UntagResourceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.UntagResourceRequest =
      zio.aws.pinpoint.model.UntagResourceRequest(resourceArn, tagKeys)
    def resourceArn: __string
    def tagKeys: List[__string]
    def getResourceArn: ZIO[Any, Nothing, __string] = ZIO.succeed(resourceArn)
    def getTagKeys: ZIO[Any, Nothing, List[__string]] = ZIO.succeed(tagKeys)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.UntagResourceRequest
  ) extends zio.aws.pinpoint.model.UntagResourceRequest.ReadOnly {
    override val resourceArn: __string = impl.resourceArn(): __string
    override val tagKeys: List[__string] = impl
      .tagKeys()
      .asScala
      .map { item =>
        item: __string
      }
      .toList
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.UntagResourceRequest
  ): zio.aws.pinpoint.model.UntagResourceRequest.ReadOnly = new Wrapper(impl)
}
